define(
//begin v1.x content
({
	"saveLabel": "Guardar",
	"saveSettingLabelOn": "Definir intervalo de guardado automático...",
	"saveSettingLabelOff": "Desactivar guardado automático",
	"saveSettingdialogTitle": "Guardado automático",
	"saveSettingdialogDescription": "Especificar intervalo de guardado automático",
	"saveSettingdialogParamName": "Intervalo de guardado automático",
	"saveSettingdialogParamLabel": "min",
	"saveSettingdialogButtonOk": "Definir intervalo",
	"saveSettingdialogButtonCancel": "Cancelar",
	"saveMessageSuccess": "Guardado a las ${0}",
	"saveMessageFail": "No se ha podido guardar a las ${0}"
})

//end v1.x content
);
